package cn.zhentao.pojo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import jakarta.validation.constraints.*;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

@Data
public class AppId {
    @NotBlank(message = "应用id不能为空")
    private String appId;
    @NotBlank(message = "签名不能为空")
    private String sign;
    @NotNull(message = "时间戳不能为空")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long reqTime=System.currentTimeMillis();
    @NotNull(message = "goodsId不能为空")
    @JsonFormat(shape = JsonFormat.Shape.STRING)
    private Integer goodsId;
    @NotNull(message = "数量不能为空")
    @DecimalMin(value = "1",message = "最小值1")
    private Integer amount;
    @NotNull(message = "价格不能为空")
    @DecimalMin(value = "0",message = "最小值0")
    @DecimalMax(value = "0",message = "最大值9999")
    private BigDecimal price;
    @NotBlank(message = "手机号不能为空")
    @Pattern(regexp="^((13[0-9])|(14[0-9])|(15([0-9]))|(166)|(17[0-9])|(18[0-9])|(19[0-9]))\\d{11}$",message ="手机号码格式错误")
    private String mobile;
    @NotNull(message = "日期不能为空")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8",shape = JsonFormat.Shape.STRING)
    private Date nowDate=new Date();
}
